import { system, world } from '@minecraft/server';

world.beforeEvents.worldInitialize.subscribe(initEvent => {
  initEvent.blockComponentRegistry.registerCustomComponent('zc_placetesting:trigger', {
    onPlace: e => {
      e.dimension.runCommand("function setblock");
    }
  });
  
  
  initEvent.blockComponentRegistry.registerCustomComponent('zc_cavee:trigger', {
  onTick: e => {
    const { x, y, z } = e.block.location;
    const dim = e.dimension;
    dim.runCommandAsync(`structure load aromic ${x} ${y} ${z}`);
    dim.runCommandAsync(`effect @p[tag=inmd] blindness 30 15 true`);
    dim.runCommandAsync(`effect @p[tag=inmd] slow_falling 120 15 true`);
    dim.runCommandAsync(`effect @p[tag=inmd] slowness 20 15 true`);
    dim.runCommandAsync(`title @p[tag=inmd] title §eLoading..`);
    dim.runCommandAsync(`setblock ${x} ${y} ${z} bedrock`);
  }
});

initEvent.blockComponentRegistry.registerCustomComponent('zc_cave1:trigger', {
  onTick: e => {
    const { x, y, z } = e.block.location;
    const dim = e.dimension;
    dim.runCommandAsync(`structure load cave1 ${x} ${y} ${z}`);
    dim.runCommandAsync(`effect @p[tag=inmd] blindness 30 15 true`);
    dim.runCommandAsync(`effect @p[tag=inmd] slow_falling 120 15 true`);
    dim.runCommandAsync(`effect @p[tag=inmd] slowness 20 15 true`);
    dim.runCommandAsync(`title @p[tag=inmd] title §eLoading..`);
    dim.runCommandAsync(`setblock ${x} ${y} ${z} bedrock`);
  }
});


  initEvent.blockComponentRegistry.registerCustomComponent('zc_arthur_portal:trigger', {
  onTick: e => {
    const { x, y, z } = e.block.location;
    const dim = e.dimension;
    dim.runCommandAsync(`effect @p[x=${x},y=${y},z=${z},r=1] blindness 10 15 true`);
    dim.runCommandAsync(`effect @p[x=${x},y=${y},z=${z},r=1] slow_falling 30 15 true`);
    dim.runCommandAsync(`effect @p[x=${x},y=${y},z=${z},r=1] slowness 10 15 true`);
    dim.runCommandAsync(`effect @p[x=${x},y=${y},z=${z},r=1, tag=!ze] levitation 30 2 true`);
    dim.runCommandAsync(`tag @p[x=${x},y=${y},z=${z},r=1] add ze`);
    dim.runCommandAsync(`tag @p[x=${x},y=${y},z=${z},r=1] add inmd`);
    dim.runCommandAsync(`fill 104999 300 104999 105001 300 105001 bedrock replace air`);
    dim.runCommandAsync(`fill 104970 220 104970 104970 220 104970 zc:cavee replace air`);
    dim.runCommandAsync(`title @p[x=${x},y=${y},z=${z},r=1] title §eLoading..`);
    dimension.runCommandAsync(`give @p[x=${x},y=${y},z=${z},r=1] zc:home_key 1 0 {"item_lock":{"mode":"lock_in_inventory"},"keep_on_death":{}}`);
    dim.runCommandAsync(`tp @p[x=${x},y=${y},z=${z},r=1] 105000 320 105000`);
  }
});

});





const CENTER = { x: 105000, y: 302, z: 105000 };
const RADIUS_SQ = 100 * 100;

system.runInterval(() => {
  for (const player of world.getPlayers({ tags: ["inmd"] })) {
    const { x, y, z } = player.location;

    const dx = x - CENTER.x;
    const dy = y - CENTER.y;
    const dz = z - CENTER.z;
    const distanceSq = dx * dx + dy * dy + dz * dz;

    
    if (distanceSq > RADIUS_SQ) {
      player.runCommandAsync(`tp @s ${CENTER.x} ${CENTER.y} ${CENTER.z}`).catch(() => {});
      player.runCommandAsync(`give @s zc:home_key 1 0 {"item_lock":{"mode":"lock_in_inventory"},"keep_on_death":{}}`).catch(() => {});
      continue;
    }

    
    if (!player.hasTag("has_home_key")) {
      try {
        const inventory = player.getComponent("minecraft:inventory")?.container;
        let hasKey = false;

        if (inventory) {
          for (let i = 0; i < inventory.size; i++) {
            const item = inventory.getItem(i);
            if (item && item.typeId === "zc:home_key") {
              hasKey = true;
              break;
            }
          }
        }

        if (!hasKey) {
          player.runCommandAsync(`give @s zc:home_key 1 0 {"item_lock":{"mode":"lock_in_inventory"},"keep_on_death":{}}`);
          player.addTag("has_home_key");
        }
      } catch (err) {
        console.warn("Error checking inventory or giving item:", err);
      }
    }
  }
}, 20); 



const overworld = world.getDimension("overworld");

system.runInterval(() => {
  overworld.runCommandAsync(`fog @a[tag=inmd] push "zc:fog_mdimension" mdimension`).catch(() => {});
  overworld.runCommandAsync(`fog @a[tag=!inmd] remove mdimension`).catch(() => {});
}, 20);




world.beforeEvents.worldInitialize.subscribe(e =>
  e.blockComponentRegistry.registerCustomComponent('zc_arthur:trigger', {
    onPlayerInteract: ev => {
      const { x, y, z } = ev.block.location;
      const base = `execute @a[hasitem={item=zc:mine_key,location=slot.weapon.mainhand}] ~~~`;
      ev.dimension.runCommand(`${base} fill ${x - 2} ${y + 1} ${z - 2} ${x + 2} ${y + 3} ${z + 2} zc:arthur_portal replace air`);
      ev.dimension.runCommand(`${base} summon lightning_bolt ${x} ${y - 1} ${z}`);
    }
  })
);













world.afterEvents.itemUse.subscribe(async ({ source, itemStack }) => {
  if (!itemStack || itemStack.typeId !== "zc:home_key") return;

  try {
    const { x, y, z } = world.getDefaultSpawnLocation(); 
    const dim = source.dimension;

    await dim.runCommandAsync(`tp "${source.name}" ${x} 200 ${z}`);
    await source.runCommandAsync(`tag @s remove inmd`);
    await source.runCommandAsync(`tag @s remove has_home_key`);
    await source.runCommandAsync(`effect @s blindness 6 3 true`);
    await source.runCommandAsync(`effect @s slow_falling 30 0 true`);
    await source.runCommandAsync(`clear @s zc:home_key`);
    await source.runCommandAsync(`title @s title §eLoading`);
  } catch (e) {
    console.warn("Home Key Teleport Error:", e);
  }
});
